@@ -1,22 +1,26 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
-"""
-Entrypoint module, in case you use `python -m limesqueezer`.
-"""
 
-#%%═════════════════════════════════════════════════════════════════════
-# IMPORT
-from . import CLI
-###═════════════════════════════════════════════════════════════════════
-doc = '''
+# Entrypoint module, in case you use `python -m limesqueezer`.
+
+'''
 Limesqueezer
-========================================================================
+============
 
 Lossy compression tools for smooth data series.
 
 Recommended abbreviation is 'ls'
 
-import limesqueezer as ls
+importing ::
+
+    import limesqueezer as ls
+
 '''
+
+#%%═════════════════════════════════════════════════════════════════════
+# IMPORT
+from . import CLI
+###═════════════════════════════════════════════════════════════════════
+
 if __name__ == "__main__":
     CLI.main()
\ No newline at end of file
